obelisk.types.IngestMode
========================

.. currentmodule:: obelisk.types

.. autoclass:: IngestMode
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~IngestMode.DEFAULT
      ~IngestMode.STREAM_ONLY
      ~IngestMode.STORE_ONLY
   
   